from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.runner_job_admin import RunnerJobAdmin


T = TypeVar("T", bound="GetApiV1RunnersJobsResponse200")


@_attrs_define
class GetApiV1RunnersJobsResponse200:
    """Attributes:
    total (Union[Unset, int]):  Example: 1.
    data (Union[Unset, list['RunnerJobAdmin']]):
    """

    total: Unset | int = UNSET
    data: Unset | list["RunnerJobAdmin"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        total = self.total

        data: Unset | list[dict[str, Any]] = UNSET
        if not isinstance(self.data, Unset):
            data = []
            for data_item_data in self.data:
                data_item = data_item_data.to_dict()
                data.append(data_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if total is not UNSET:
            field_dict["total"] = total
        if data is not UNSET:
            field_dict["data"] = data

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.runner_job_admin import RunnerJobAdmin

        d = dict(src_dict)
        total = d.pop("total", UNSET)

        data = []
        _data = d.pop("data", UNSET)
        for data_item_data in _data or []:
            data_item = RunnerJobAdmin.from_dict(data_item_data)

            data.append(data_item)

        get_api_v1_runners_jobs_response_200 = cls(total=total, data=data)

        get_api_v1_runners_jobs_response_200.additional_properties = d
        return get_api_v1_runners_jobs_response_200

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
