from enum import IntEnum


class NSFWFlag(IntEnum):
    """NSFWFlag class."""

    VALUE_0 = 0
    VALUE_1 = 1
    VALUE_2 = 2
    VALUE_4 = 4

    def __str__(self) -> str:
        return str(self.value)
