from typing import Any

import httpx

from peertube.api.shared_utils import build_response, parse_response
from peertube.client import AuthenticatedClient, Client
from peertube.models.notification_type import NotificationType
from peertube.types import UNSET, Response, Unset


def _get_kwargs(
    *,
    type_one_of: Unset | list[NotificationType] = UNSET,
    unread: Unset | bool = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    json_type_one_of: Unset | list[int] = UNSET
    if not isinstance(type_one_of, Unset):
        json_type_one_of = []
        for type_one_of_item_data in type_one_of:
            type_one_of_item = type_one_of_item_data.value
            json_type_one_of.append(type_one_of_item)

    params["typeOneOf"] = json_type_one_of

    params["unread"] = unread

    params["start"] = start

    params["count"] = count

    params["sort"] = sort
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/api/v1/users/me/notifications",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Any | None:
    return parse_response(client=client, response=response)


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[Any]:
    return build_response(client=client, response=response)


def sync_detailed(
    *,
    client: AuthenticatedClient,
    type_one_of: Unset | list[NotificationType] = UNSET,
    unread: Unset | bool = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> Response[Any]:
    """List my notifications


    Args:
        type_one_of (Union[Unset, list[NotificationType]]): Parameter for type one of.
        unread (Union[Unset, bool]): Parameter for unread.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, str]):  Example: -createdAt.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        type_one_of=type_one_of, unread=unread, start=start, count=count, sort=sort
    )

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    type_one_of: Unset | list[NotificationType] = UNSET,
    unread: Unset | bool = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> Any | None:
    """List my notifications


    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any
    """

    return sync_detailed(
        client=client,
        type_one_of=type_one_of,
        unread=unread,
        start=start,
        count=count,
        sort=sort,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    type_one_of: Unset | list[NotificationType] = UNSET,
    unread: Unset | bool = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> Response[Any]:
    """List my notifications


    Args:
        type_one_of (Union[Unset, list[NotificationType]]): Parameter for type one of.
        unread (Union[Unset, bool]): Parameter for unread.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, str]):  Example: -createdAt.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        type_one_of=type_one_of, unread=unread, start=start, count=count, sort=sort
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)
