from enum import IntEnum


class RunnerJobState(IntEnum):
    """RunnerJobState enumeration."""

    VALUE_1 = 1
    VALUE_2 = 2
    VALUE_3 = 3
    VALUE_4 = 4
    VALUE_5 = 5
    VALUE_6 = 6
    VALUE_7 = 7
    VALUE_8 = 8

    def __str__(self) -> str:
        """Return string representation."""

        return str(self.value)
